package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.vo.UserLoginVo;
import com.caimei365.user.service.LoginService;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;

/**
 * 登录API
 *
 * @author : Charles
 * @date : 2021/3/8
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/login")
public class LoginApi {

    private final LoginService loginService;

    /**
     * 登录(用户名，密码)
     *
     * spi旧接口：user/login
     *
     * @param mobileOrEmail 手机号或邮箱
     * @param password 密码
     * @return BaseUser
     */
    @PostMapping("/password")
    public ResponseJson<UserLoginVo> passwordLogin(String mobileOrEmail, String password) {
        return loginService.passwordLogin(mobileOrEmail, password);
    }

    /**
     * 微信授权登录(小程序)
     *
     * @param code          微信授权code
     * @param encryptedData 微信加密数据
     * @param iv            加密算法的初始向量
     */
    @PostMapping("/auth/applets")
    public ResponseJson<UserLoginVo> appletsAuthorization(String code, String encryptedData, String iv, @RequestHeader HttpHeaders headers) {
        return loginService.appletsAuthorization(code, encryptedData, iv, headers);
    }

    /**
     * 微信公众号授权链接(www)
     *
     * spi旧接口：user/authorizationLink
     *
     * @param redirectUri 用于微信授权的中间页面
     * @param mode        授权方式：1静默授权，其他手动同意授权
     */
    @GetMapping("/auth/link")
    public ResponseJson<String> getAuthorizationLink(String redirectUri, Integer mode) {
        return loginService.getAuthorizationLink(redirectUri, mode);
    }

    /**
     * 微信公众号授权登录(www)
     *
     * spi旧接口：user/authorizationLogin
     *
     * @param code  微信code
     * @param state 安全认证
     * @param mode  1:静默授权,2:用户手动授权
     */
    @GetMapping("/auth/website")
    public ResponseJson<UserLoginVo> websiteAuthorization(String code, String state, Integer mode, @RequestHeader HttpHeaders headers) {
        return loginService.websiteAuthorization(code, state, mode, headers);
    }

    /**
     * 微信扫码登录
     *
     * spi旧接口：user/wechatLogin
     *
     * @param code      微信code
     * @param state     安全认证
     */
    @GetMapping("/auth/qrCode")
    public void qrCodeAuthorization(String code, String state) {
        loginService.qrCodeAuthorization(code, state);
    }

}
