package com.caimei365.user.mapper;

import com.caimei365.user.model.po.OperationPo;
import com.caimei365.user.model.vo.UserLoginVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/5
 */
@Mapper
public interface LoginMapper {
    /**
     * 根据用户id获取用户
     *
     * @param userId 手机号
     * @return baseuser
     */
    UserLoginVo getLoginUserByUserId(@Param("userId") Integer userId);
    /**
     * 根据手机号或邮箱获取用户
     *
     * @param mobileOrEmail 手机号/邮箱
     * @return BaseUser
     */
    UserLoginVo getLoginUserByMobileOrEmail(@Param("mobileOrEmail") String mobileOrEmail);
    /**
     * 根据手机号获取运营人员
     *
     * @param mobile 手机号
     * @return BaseUser
     */
    OperationPo getOperationByMobile(@Param("mobile") String mobile);

    /**
     * 根据openId获取协销
     * @param openId openId
     * @return BaseUser
     */
    UserLoginVo getServiceProviderByOpenId(@Param("openId") String openId);

    /**
     * 根据用户ID更新协销unionId
     * @param userId
     * @param unionId
     */
    void updateServiceProviderUnionId(@Param("userId") Integer userId, @Param("unionId") String unionId);

    /**
     * 根据unionId获取运营人员
     * @param unionId unionId
     * @param source
     * @return BaseUser
     */
    UserLoginVo getOperationUserByUnionId(@Param("unionId") String unionId, @Param("source") String source);
    /**
     * 根据openId获取运营人员
     * @param openId
     * @param source
     * @return
     */
    UserLoginVo getOperationUserByOpenId(@Param("openId") String openId, @Param("source") String source);
    /**
     * 根据用户ID更新运营人员openId
     * @param userId
     * @param openId
     */
    void updateOperationOpenId(@Param("userId") Integer userId, @Param("openId") String openId);
    /**
     * 根据用户ID更新运营人员unionId
     * @param userId
     * @param unionId
     */
    void updateOperationUnionId(@Param("userId") Integer userId, @Param("unionId") String unionId);
    /**
     * 根据openId获取用户Id
     * @param openId
     * @param source
     * @return
     */
    Integer getUserIdByOpenId(@Param("openId") String openId, @Param("source") String source);


}
